###############
IGWN Robot Auth
###############

.. automodule:: igwn_robot_auth
    :no-index:

==============
Project status
==============

.. image:: https://badge.fury.io/py/igwn-robot-auth.svg
    :target: http://badge.fury.io/py/igwn-robot-auth
    :alt: igwn-robot-auth PyPI version badge
.. image:: https://img.shields.io/conda/vn/conda-forge/igwn-robot-auth.svg
    :target: https://anaconda.org/conda-forge/igwn-robot-auth/
    :alt: igwn-robot-auth conda-forge badge

.. image:: https://img.shields.io/pypi/l/igwn-robot-auth.svg
    :target: https://choosealicense.com/licenses/mit/
    :alt: igwn-robot-auth license badge

.. raw:: html

    <br>

.. image:: https://img.shields.io/gitlab/issues/open/computing%2Fsoftware%2Figwn-robot-auth?gitlab_url=https%3A%2F%2Fgit.ligo.org
    :target: https://git.ligo.org/computing/software/igwn-robot-auth/issues/
    :alt: GitLab Issues

.. image:: https://img.shields.io/gitlab/merge-requests/open/computing%2Fsoftware%2Figwn-robot-auth?gitlab_url=https%3A%2F%2Fgit.ligo.org
    :target: https://git.ligo.org/computing/software/igwn-robot-auth/merge_requests/
    :alt: GitLab Merge Requests

=============
Documentation
=============

.. toctree::
    :maxdepth: 1

    Installation <install>
    Usage <usage>
    Automation <auto>
    Containerisation <container>

.. toctree::
    :maxdepth: 1
    :caption: Modules

    api/igwn_robot_auth
    api/igwn_robot_auth.htcondor

.. toctree::
    :caption: Command-line utilities
    :maxdepth: 1

    igwn-robot-get

.. toctree::
    :caption: Extras
    :maxdepth: 1

    Changelog <changelog>